pub struct ResolvedDep {
pub name: String,
pub version: String,
pub enabled_features: Vec<String>,
pub available_features: Vec<String>,
pub source: Option<String>,
pub repository: Option<String>,
pub is_direct: bool,
}Expand description
A resolved dependency with its name, version, and enabled features.
Fields
name: Stringversion: Stringenabled_features: Vec<String>Features that are actually enabled in the resolved build plan.
available_features: Vec<String>All features declared by the crate (available but not necessarily enabled).
source: Option<String>repository: Option<String>is_direct: boolTrait Implementations
Sourceimpl Clone for ResolvedDep
impl Clone for ResolvedDep
Sourcefn clone(&self) -> ResolvedDep
fn clone(&self) -> ResolvedDep
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedDep
impl Debug for ResolvedDep